﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Grids;
using System.Windows.Markup;
using System.ComponentModel;

namespace TestApp
{
    public partial class MainPage : UserControl
    {
        public Model model = new Model();
        ObservableCollection<Row> Rows = new ObservableCollection<Row>();
        string[] keys = new string[] { "Key1", "Key2", "Key3" };


        public MainPage()
        {
            InitializeComponent();

            int numOfColumns = 3;

            for (int i = 0; i < 10; i++)
            {
                Row r = new Row();
                for (int j = 0; j < numOfColumns; j++)
                {
                    Cell c = new Cell();
                    c.Key = keys[j];
                    c.Value = String.Format("{0}{1}", i, j);
                    r.Cells.Add(c);
                }
                r.RowIndex = i;
                Rows.Add(r);
            }

            for (int i = 0; i < numOfColumns; i++)
            {
                UnboundColumn column = new UnboundColumn();
                column.ItemTemplate = Create(String.Format("RowData.Cells[{0}].Value", i));
                column.EditorTemplate = Create(String.Format("RowData.Cells[{0}].Value", i));
                column.Key = keys[i];
                XamGrid.Columns.Add(column);
            }

            this.model.Rows = this.Rows;
            this.XamGrid.DataContext = this.model;
        }


        public static DataTemplate Create(string path)
        {
            return (DataTemplate)XamlReader.Load(
                @"<DataTemplate
                xmlns=""http://schemas.microsoft.com/client/2007""
                xmlns:uc=""clr-namespace:TestApp;assembly=TestApp"">
                <uc:XText MyText=""{Binding Path=" + path + @", Mode=TwoWay}""/>
              </DataTemplate>"
              );
        }
    }


    public class Model : INotifyPropertyChanged
    {
        private string test;
        public string Test
        {
            get { return this.test; }
            set
            {
                this.test = value;
                this.RaisePropertyChanged("Test");
            }
        }

        private ObservableCollection<Row> rows = new ObservableCollection<Row>();
        public ObservableCollection<Row> Rows
        {
            get
            {
                return this.rows;
            }
            set
            {
                this.rows = value;
                this.RaisePropertyChanged("Rows");


            }
        }
        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string propertyName)
        {
            System.ComponentModel.PropertyChangedEventHandler propertyChanged = this.PropertyChanged;
            if ((propertyChanged != null))
            {
                propertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }

    public class Row : INotifyPropertyChanged
    {
        public Row()
        {

        }

        private int rowIndex { get; set; }
        public int RowIndex
        {
            get
            { return this.rowIndex; }

            set
            {
                this.rowIndex = value;
                this.RaisePropertyChanged("RowIndex");
            }
        }

        private List<Cell> cells = new List<Cell>();
        public List<Cell> Cells
        {
            get
            {
                return this.cells;
            }
            set
            {
                this.cells = value;
                this.RaisePropertyChanged("Cells");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler propertyChanged = this.PropertyChanged;
            if (propertyChanged != null)
            {
                propertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }

    public class Cell : INotifyPropertyChanged
    {
        public string Key { get; set; }

        private string value;
        public string Value
        {
            get
            {
                return this.value;
            }
            set
            {
                this.value = value;
                this.RaisePropertyChanged("Value");
            }
        }
        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler propertyChanged = this.PropertyChanged;
            if (propertyChanged != null)
            {
                propertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
